# Generated by Django 5.2.5 on 2026-01-07 05:00

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_routing', '0016_ospfinterface_interface_onetoonefield'),
        ('users', '0015_owner'),
    ]

    operations = [
        migrations.AddField(
            model_name='bgpaddressfamily',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='bgppeer',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='bgppeeraddressfamily',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='bgppeertemplate',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='bgppoliytemplate',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='bgprouter',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='bgpscope',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='bgpsessiontemplate',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='bgpsetting',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='eigrpaddressfamily',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='eigrpinterface',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='eigrpnetwork',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='eigrprouter',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='ospfarea',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='ospfinstance',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='ospfinterface',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='prefixlist',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='prefixlistentry',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='routemap',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='routemapentry',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
        migrations.AddField(
            model_name='staticroute',
            name='owner',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to='users.owner',
            ),
        ),
    ]
