# Generated by Django 4.1.7 on 2023-05-18 13:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_routing', '0003_model_ordering_and_constraints'),
    ]

    operations = [
        migrations.AlterField(
            model_name='prefixlistentry',
            name='ge',
            field=models.PositiveSmallIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='prefixlistentry',
            name='le',
            field=models.PositiveSmallIntegerField(blank=True, null=True),
        ),
    ]
