# Generated by Django 5.2.5 on 2025-09-05 23:41

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_routing', '0015_alter_ospfarea_options_alter_ospfinstance_options'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='ospfinterface',
            name='netbox_routing_ospfinterface_unique_interface',
        ),
        migrations.AlterField(
            model_name='ospfinterface',
            name='interface',
            field=models.OneToOneField(
                on_delete=django.db.models.deletion.CASCADE,
                related_name='ospf_interfaces',
                to='dcim.interface',
            ),
        ),
    ]
