# Generated by Django 5.2.5 on 2026-02-18 19:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_routing', '0026_denormalized_matches'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bgppeer',
            name='name',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='bgprouter',
            name='name',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]
