{% extends 'generic/object.html' %}
{% load humanize %}
{% load helpers %}
{% load plugins %}

{% block content %}
<div class="row">
  <div class="col col-md-6">
    <div class="card">
      <h5 class="card-header">AS Path Entry</h5>
      <div class="card-body">
        <table class="table table-hover attr-table">
          <tr>
            <th scope="row">AS Path Entry</th>
            <td>
              {{ object.aspath|linkify }}
            </td>
          </tr>
          <tr>
            <th scope="row">Action</th>
            <td>
              {{ object.action }}
            </td>
          </tr>
          <tr>
            <th scope="row">Sequence</th>
            <td>
              {{ object.sequence }}
            </td>
          </tr>
          <tr>
            <th scope="row">ASN</th>
            <td>
              {{ object.asn|linkify }}
            </td>
          </tr>
        </table>
      </div>
    </div> 
      {% plugin_left_page object %}
  </div>
  <div class="col col-md-6">
    {% include 'inc/panels/related_objects.html' %}
    {% include 'inc/panels/custom_fields.html' %}
    {% include 'inc/panels/comments.html' %}
    {% include 'inc/panels/tags.html' %}
    {% plugin_right_page object %}
  </div>
</div>
<div class="row">
    <div class="col col-md-12">
        {% plugin_full_width_page object %}
    </div>
</div>
{% endblock %}