# Generated by Django 5.2.4 on 2025-08-02 20:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_routing', '0014_ospfarea_area_type'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='ospfarea',
            options={'ordering': ['area_id']},
        ),
        migrations.AlterModelOptions(
            name='ospfinstance',
            options={'ordering': ['vrf', 'router_id', 'process_id']},
        ),
    ]
