{% extends 'generic/object.html' %}
{% load humanize %}
{% load helpers %}
{% load plugins %}

{% block content %}
<div class="row">
  <div class="col col-md-6">
    <div class="card">
      <h5 class="card-header">BGP Peer Address Family</h5>
      <table class="table table-hover attr-table">
        <tr>
          <th scope="row">Assigned Object</th>
          <td>
            {{ object.assigned_object|linkify }}
          </td>
        </tr>
        <tr>
          <th scope="row">Address Family</th>
          <td>
            {{ object.address_family|linkify }}
          </td>
        </tr>
        <tr>
          <th scope="row">Enabled</th>
          <td>
            {{ object.enabled }}
          </td>
        </tr>
        <tr>
          <th scope="row">Route Map (in)</th>
          <td>
            {{ object.routemap_in|linkify }}
          </td>
        </tr>
        <tr>
          <th scope="row">Route Map (out)</th>
          <td>
            {{ object.routemap_out|linkify }}
          </td>
        </tr>
        <tr>
          <th scope="row">Prefix List (in)</th>
          <td>
            {{ object.prefixlist_in|linkify }}
          </td>
        </tr>
        <tr>
          <th scope="row">Prefix List (out)</th>
          <td>
            {{ object.prefixlist_out|linkify }}
          </td>
        </tr>
      </table>
    </div>
    {% include 'netbox_routing/inc/settings.html' %}
    {% plugin_left_page object %}
  </div>
  <div class="col col-md-6">
    {% include 'inc/panels/related_objects.html' %}
    {% include 'inc/panels/custom_fields.html' %}
    {% include 'inc/panels/comments.html' %}
    {% include 'inc/panels/tags.html' %}
    {% plugin_right_page object %}
  </div>
</div>
<div class="row">
    <div class="col col-md-12">
        {% plugin_full_width_page object %}
    </div>
</div>
{% endblock %}