# Generated by Django 5.2.5 on 2026-02-13 19:44

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_routing', '0022_peer_add_status'),
    ]

    operations = [
        migrations.AddField(
            model_name='bgppeer',
            name='ttl',
            field=models.PositiveSmallIntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(255),
                ],
            ),
        ),
        migrations.AddField(
            model_name='bgpsessiontemplate',
            name='ttl',
            field=models.PositiveSmallIntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(255),
                ],
            ),
        ),
    ]
