# Generated by Django 5.0.8 on 2024-09-28 03:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_routing', '0010_eigrp'),
    ]

    operations = [
        migrations.AddField(
            model_name='ospfinterface',
            name='passive',
            field=models.BooleanField(blank=True, null=True),
        ),
    ]
