{% extends 'generic/object.html' %}
{% load humanize %}
{% load helpers %}
{% load plugins %}

{% block content %}
<div class="row">
  <div class="col col-md-6">
    <div class="card">
      <h5 class="card-header">Prefix List Entry</h5>
      <table class="table table-hover attr-table">
        <tr>
          <th scope="row">Prefix List</th>
          <td>
            {{ object.prefix_list|linkify }}
          </td>
        </tr>
        <tr>
          <th scope="row">Sequence</th>
          <td>
            {{ object.sequence }}
          </td>
        </tr>
        <tr>
          <th scope="row">Type</th>
          <td>
            {% badge object.assigned_prefix_type %}
          </td>
        </tr>
        <tr>
          <th scope="row">Prefix</th>
          <td>
            {{ object.assigned_prefix|linkify|placeholder }}
          </td>
        </tr>
        <tr>
          <th scope="row">GE</th>
          <td>
            {{ object.ge }}
          </td>
        </tr>
        <tr>
          <th scope="row">LE</th>
          <td>
            {{ object.le }}
          </td>
        </tr>
      </table>
    </div>
      {% plugin_left_page object %}
  </div>
  <div class="col col-md-6">
    {% include 'inc/panels/related_objects.html' %}
    {% include 'inc/panels/custom_fields.html' %}
    {% include 'inc/panels/comments.html' %}
    {% include 'inc/panels/tags.html' %}
    {% plugin_right_page object %}
  </div>
</div>
<div class="row">
    <div class="col col-md-12">
        {% plugin_full_width_page object %}
    </div>
</div>
{% endblock %}