# Generated by Django 5.1.8 on 2025-04-21 21:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_routing', '0012_osfp_instance_vrf'),
    ]

    operations = [
        migrations.AddField(
            model_name='staticroute',
            name='tag',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
