# Generated by Django 5.2.5 on 2026-01-16 23:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_routing', '0017_netbox_v040500'),
    ]

    operations = [
        migrations.DeleteModel(
            name='BGPPoliyTemplate',
        ),
        migrations.DeleteModel(
            name='BGPSessionTemplate',
        ),
        migrations.DeleteModel(
            name='BGPPeerTemplate',
        ),
        migrations.DeleteModel(
            name='BGPPeerAddressFamily',
        ),
        migrations.DeleteModel(
            name='BGPPeer',
        ),
        migrations.DeleteModel(
            name='BGPScope',
        ),
        migrations.DeleteModel(
            name='BGPAddressFamily',
        ),
        migrations.DeleteModel(
            name='BGPRouter',
        ),
        migrations.DeleteModel(
            name='BGPSetting',
        ),
    ]
