{% extends 'generic/object_children.html' %}
{% load helpers %}

{% block bulk_extra_controls %}
    {{ block.super }}
    {% if perms.netbox_routing.add_ospfinterface %}
        <div class="btn-group" role="group">
            <a href="{% url 'plugins:netbox_routing:ospfinterface_add' %}?{{ form_interface_assignment }}={{ object.pk }}&return_url={{ return_url }}"
               class="btn btn-primary btn-sm">
                <i class="mdi mdi-plus-thick" aria-hidden="true"></i> Add Interfaces
            </a>
        </div>
    {% endif %}
{% endblock bulk_extra_controls %}
