{% extends 'generic/object.html' %}
{% load render_table from django_tables2 %}
{% load helpers %}
{% load static %}

{% block content %}
  {% include 'inc/table_controls_htmx.html' with table_modal="StaticRouteDevices_config" %}
  
  <form method="post">
    {% csrf_token %}

    <div class="card">
      <div class="card-body htmx-container table-responsive" id="object_list">
        {% include 'htmx/table.html' %}
      </div>
    </div>
  </form>
{% endblock %}

{% block modals %}
  {{ block.super }}
  {% table_config_form table table_name="StaticRouteDevices"%}
{% endblock modals %}