# Generated by Django 5.0.8 on 2024-09-14 01:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            'netbox_routing',
            '0007_bgpsessiontemplate_asn_bgpsessiontemplate_bfd_and_more',
        ),
    ]

    operations = [
        migrations.AddField(
            model_name='bgpaddressfamily',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='bgpaddressfamily',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='bgppeer',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='bgppeer',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='bgppeeraddressfamily',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='bgppeeraddressfamily',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='bgppeertemplate',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='bgppeertemplate',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='bgppoliytemplate',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='bgppoliytemplate',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='bgprouter',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='bgprouter',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='bgpscope',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='bgpscope',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='bgpsessiontemplate',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='bgpsessiontemplate',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='bgpsetting',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='bgpsetting',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='ospfarea',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='ospfarea',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='ospfinstance',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='ospfinstance',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='ospfinterface',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='ospfinterface',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='prefixlist',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='prefixlist',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='prefixlistentry',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='prefixlistentry',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='routemap',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='routemap',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='routemapentry',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='routemapentry',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='staticroute',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='staticroute',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
    ]
