# Generated by Django 4.1.7 on 2023-05-18 13:43

from django.db import migrations, models
import utilities.json


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_routing', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='prefixlist',
            name='custom_field_data',
            field=models.JSONField(
                blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder
            ),
        ),
        migrations.AlterField(
            model_name='prefixlistentry',
            name='custom_field_data',
            field=models.JSONField(
                blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder
            ),
        ),
        migrations.AlterField(
            model_name='routemap',
            name='custom_field_data',
            field=models.JSONField(
                blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder
            ),
        ),
        migrations.AlterField(
            model_name='routemapentry',
            name='custom_field_data',
            field=models.JSONField(
                blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder
            ),
        ),
        migrations.AlterField(
            model_name='staticroute',
            name='custom_field_data',
            field=models.JSONField(
                blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder
            ),
        ),
    ]
