# Generated by Django 5.2.9 on 2026-02-17 18:07

import netbox_routing.fields.ip
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_routing', '0027_bgp_name_optional'),
    ]

    operations = [
        migrations.AddField(
            model_name='staticroute',
            name='interface_next_hop',
            field=models.CharField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='staticroute',
            name='next_hop',
            field=netbox_routing.fields.ip.IPAddressField(blank=True, null=True),
        ),
    ]
