# Generated by Django 5.0.9 on 2024-11-10 22:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_routing", "0013_staticroute_tag"),
    ]

    operations = [
        migrations.AddField(
            model_name="ospfarea",
            name="area_type",
            field=models.CharField(default="standard"),
        ),
    ]
