# Generated by Django 5.2.5 on 2026-02-13 19:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_routing', '0021_bgp'),
    ]

    operations = [
        migrations.AddField(
            model_name='bgppeer',
            name='status',
            field=models.CharField(blank=True, max_length=10, null=True),
        ),
    ]
